@@ -9,7 +9,7 @@
 # copyright (c) 2009, Marcelo Mollinari                               #
 #                                                                     #
 # First version: 02/27/2009                                           #
-# Last update: 02/27/2009                                             #
+# Last update: 09/25/2009                                             #
 # License: GNU General Public License version 2 (June, 1991) or later #
 #                                                                     #
 #######################################################################
@@ -18,11 +18,11 @@
 # makes a list with 'plausible' linkage phases, with the respective
 # recombination fractions
 phases <- 
-function(w, LOD=0, max.rf=0.50) {
+function(input.seq, LOD=0, max.rf=0.50) {
   # checking for correct object
-  if(!any(class(w)=="sequence")) stop(deparse(substitute(w))," is not an object of class 'sequence'")
+  if(!any(class(input.seq)=="sequence")) stop(deparse(substitute(input.seq))," is not an object of class 'sequence'")
   
-  tot <- choose(length(w$seq.num),2)
+  tot <- choose(length(input.seq$seq.num),2)
   # initial values for the recombination fraction
   rf.init <- vector("list",tot)
   # initially relevant linkage phases
@@ -30,12 +30,12 @@ function(w, LOD=0, max.rf=0.50) {
   
   temp <- matrix(NA,4,2)
   
-  for (i in 2:length(w$seq.num)) {
+  for (i in 2:length(input.seq$seq.num)) {
     for (j in 1:(i-1)) {
 	  # recover values from two-point analyses
-      big <- pmax.int(w$seq.num[i],w$seq.num[j])
-      small <- pmin.int(w$seq.num[i],w$seq.num[j])
-      temp <- get(w$twopt)$analysis[acum(big-2)+small,,]
+      big <- pmax.int(input.seq$seq.num[i],input.seq$seq.num[j])
+      small <- pmin.int(input.seq$seq.num[i],input.seq$seq.num[j])
+      temp <- get(input.seq$twopt)$analysis[acum(big-2)+small,,]
       
       # check which assignments meet the criteria
       relevant <- which(temp[,2]>(max(temp[,2])-0.005)) # maximum LOD scores
